aboutsummaryrefslogtreecommitdiffstats
path: root/cmake/modules/FindMATH.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/modules/FindMATH.cmake')
-rw-r--r--cmake/modules/FindMATH.cmake14
1 files changed, 8 insertions, 6 deletions
diff --git a/cmake/modules/FindMATH.cmake b/cmake/modules/FindMATH.cmake
index 74175c34b3..9a6dd07149 100644
--- a/cmake/modules/FindMATH.cmake
+++ b/cmake/modules/FindMATH.cmake
@@ -1,15 +1,15 @@
# - Find math
# Find the native MATH includes and library
#
-# MATH_INCLUDE_DIR - where to find math.h, etc.
-# MATH_LIBRARIES - List of libraries when using math.
-# MATH_FOUND - True if math found.
+# MATH_INCLUDE_DIRS - where to find math.h, etc.
+# MATH_LIBRARIES - List of libraries when using math.
+# MATH_FOUND - True if math found.
-IF (MATH_INCLUDE_DIR)
+IF (MATH_INCLUDE_DIRS)
# Already in cache, be silent
SET(MATH_FIND_QUIETLY TRUE)
-ENDIF (MATH_INCLUDE_DIR)
+ENDIF (MATH_INCLUDE_DIRS)
FIND_PATH(MATH_INCLUDE_DIR math.h)
@@ -23,8 +23,10 @@ FIND_PACKAGE_HANDLE_STANDARD_ARGS(MATH DEFAULT_MSG MATH_LIBRARY MATH_INCLUDE_DIR
IF(MATH_FOUND)
SET( MATH_LIBRARIES ${MATH_LIBRARY} )
+ SET( MATH_INCLUDE_DIRS ${MATH_INCLUDE_DIR} )
ELSE(MATH_FOUND)
SET( MATH_LIBRARIES )
+ SET( MATH_INCLUDE_DIRS )
ENDIF(MATH_FOUND)
-MARK_AS_ADVANCED( MATH_LIBRARY MATH_INCLUDE_DIR )
+MARK_AS_ADVANCED( MATH_LIBRARIES MATH_INCLUDE_DIRS )